@@ -45,7 +45,16 @@ class Value1D:
 
 
 class VariableList2D:
+    """Represents a list of 2D values, like position or velocity."""
+
     def __init__(self, name: str, initial: np.ndarray):
+        """Takes a variable name and a 1D array with the first value.
+
+        :param name: Name of the variable (with unit)
+        :type name: str
+        :param initial: Initial value of the variable. ex `np.ndarray([0, 0])`
+        :type initial: np.ndarray
+        """
         match = U_RE.match(name)
         self.unit = (match.group("unit") or "").strip()
         self.var_name = match.group("name").strip()
@@ -59,10 +68,16 @@ class VariableList2D:
         return cls(name, arr)
 
     def append(self, x, y):
+        """Creates a 1D array and appends it to the list."""
         arr = np.array([x, y])
         self.add(arr)
 
     def add(self, arr: np.ndarray):
+        """Adds an x, y pair to the list.
+
+        :param arr: A pair, like `np.array([1, 2])`
+        :type arr: np.ndarray
+        """
         if self.vals.size == np.array([]).size:
             self.vals = np.array([arr])
         else:
@@ -107,11 +122,15 @@ class VariableList2D:
 
     @property
     def value(self):
+        """The current, most recent value in the list.
+
+        :rtype: np.ndarray
+        """
         return self.vals[-1]
 
     @property
     def x_values(self):
-        return np.array([x[0] for x in self.vals])
+        return self.vals.T[0]
 
     @property
     def x_name(self):
@@ -119,7 +138,7 @@ class VariableList2D:
 
     @property
     def y_values(self):
-        return np.array([x[1] for x in self.vals])
+        return self.vals.T[1]
 
     @property
     def y_name(self):
